@@ -273,8 +273,8 @@ typedef struct
 
 //! Quantum expression adapter.
 /**
- * Both ImageMagick and GraphicsMagick define an enum type for quantum-level
- * expressions, but they're different types. The QuantumExpressionOperator
+ * ImageMagick defines an enum type for quantum-level expressions,
+ * but they're different types. The QuantumExpressionOperator
  * type is an adapter type that can be mapped to either one.
  */
 typedef enum _QuantumExpressionOperator
@@ -310,10 +310,8 @@ typedef enum _QuantumExpressionOperator
     AbsQuantumOperator, /**< abs */
     ExponentialQuantumOperator, /**< exponential */
     MedianQuantumOperator, /**< median */
-    SumQuantumOperator /**< sum */
-#if defined(IMAGEMAGICK_GREATER_THAN_EQUAL_6_8_9)
-    , RootMeanSquareQuantumOperator /** root mean square */
-#endif
+    SumQuantumOperator, /**< sum */
+    RootMeanSquareQuantumOperator /** root mean square */
 } QuantumExpressionOperator ;
 
 
@@ -351,7 +349,7 @@ EXTERN VALUE Class_Chromaticity;
 EXTERN VALUE Class_Color;
 EXTERN VALUE Class_Font;
 EXTERN VALUE Class_Geometry;
-EXTERN VALUE Class_GeometryValue;   // Defined in RMagick.rb
+EXTERN VALUE Class_GeometryValue;   // Defined in rmagick_internal.rb
 EXTERN VALUE Class_Pixel;
 EXTERN VALUE Class_Point;
 EXTERN VALUE Class_PolaroidOptions;
@@ -1227,13 +1225,8 @@ MagickExport void UnityAddKernelInfo(KernelInfo *kernel, const double scale);
 MagickExport void ScaleKernelInfo(KernelInfo *kernel, const double scaling_factor, const GeometryFlags normalize_flags);
 #endif
 
-#if (RUBY_VERSION_MAJOR == 2 && RUBY_VERSION_MINOR < 7)
-    #define RESCUE_FUNC(func)                   (VALUE (*)(ANYARGS))(func)
-    #define RESCUE_EXCEPTION_HANDLER_FUNC(func) (VALUE (*)(ANYARGS))(func)
-#else
-    #define RESCUE_FUNC(func)                   (VALUE(*)(VALUE))(func)
-    #define RESCUE_EXCEPTION_HANDLER_FUNC(func) (VALUE(*)(VALUE, VALUE))(func)
-#endif
+#define RESCUE_FUNC(func)                   (VALUE(*)(VALUE))(func)
+#define RESCUE_EXCEPTION_HANDLER_FUNC(func) (VALUE(*)(VALUE, VALUE))(func)
 
 } // extern "C"
 
