@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 RSpec.describe Magick::Image, "#colormap" do
   it "works" do
     image = described_class.new(20, 20)
@@ -5,7 +7,7 @@ RSpec.describe Magick::Image, "#colormap" do
     # IndexError b/c image is DirectClass
     expect { image.colormap(0) }.to raise_error(IndexError)
     # Read PseudoClass image
-    pc_image = described_class.read(IMAGES_DIR + '/Button_0.gif').first
+    pc_image = described_class.read(IMAGES_DIR + '/Button_0.gif') { |info| info.depth = 8 }.first
     expect { pc_image.colormap(0) }.not_to raise_error
     ncolors = pc_image.colors
     expect { pc_image.colormap(ncolors + 1) }.to raise_error(IndexError)
@@ -19,7 +21,13 @@ RSpec.describe Magick::Image, "#colormap" do
     result = pc_image.colormap(0, 'red')
     expect(result).to eq(old_color)
     result = pc_image.colormap(0)
-    expect(result).to eq('red')
+    expected = value_by_version(
+      "6.8": "#FF0000",
+      "6.9": "#FF0000FF",
+      "7.0": "#FF0000FF",
+      "7.1": "#FF0000FF"
+    )
+    expect(result).to eq(expected)
 
     pixel = Magick::Pixel.new(Magick::QuantumRange)
     expect { pc_image.colormap(0, pixel) }.not_to raise_error
@@ -27,6 +35,6 @@ RSpec.describe Magick::Image, "#colormap" do
     expect { pc_image.colormap(0, pixel, Magick::BlackChannel) }.to raise_error(ArgumentError)
     expect { pc_image.colormap(0, [2]) }.to raise_error(TypeError)
     pc_image.freeze
-    expect { pc_image.colormap(0, 'red') }.to raise_error(FreezeError)
+    expect { pc_image.colormap(0, 'red') }.to raise_error(FrozenError)
   end
 end
