@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 RSpec.describe Magick::Image, '#profile!' do
   it 'works' do
     image = described_class.new(20, 20)
@@ -14,8 +16,8 @@ RSpec.describe Magick::Image, '#profile!' do
     expect { image.profile!('test', 'foobarbaz') }.to raise_error(ArgumentError)
 
     image.freeze
-    expect { image.profile!('icc', 'xxx') }.to raise_error(FreezeError)
-    expect { image.profile!('*', nil) }.to raise_error(FreezeError)
+    expect { image.profile!('icc', 'xxx') }.to raise_error(FrozenError)
+    expect { image.profile!('*', nil) }.to raise_error(FrozenError)
   end
 
   it 'delete exif when nil given as profile' do
